#include "ADoc.h"

#include "XmlConf.h"
#include "crypto/cert/X509CertStore.h"
#include "util/File.h"
#include "version.h"

#include <xsec/utils/XSECPlatformUtils.hpp>

#include <openssl/conf.h>
#include <openssl/ssl.h>

namespace digidoc
{
static std::string m_appInfo = "";
}

using namespace digidoc;

/**
 * Returns appInfo string
 */
std::string digidoc::appInfo() { return m_appInfo; }

/**
 * Return libdigidocpp version
 */
std::string digidoc::version() { return VER_STR(FILE_VER_DOT); }

/**
 * Initializes libraries used in digidoc implementation.
 */
void digidoc::initialize(const std::string &appInfo)
{
    m_appInfo = appInfo;

    // Initialize OpenSSL library.
    SSL_load_error_strings();
    SSL_library_init();
    OPENSSL_config(0);

    // Initialize Apache Xerces library.
    xercesc::XMLPlatformUtils::Initialize();

    // Initialize Apache XML Security library.
    XSECPlatformUtils::Initialise();

    // Use Xml based configuration
    XmlConf::initialize();

    // Init default cert store
    X509CertStore::init();
}

/**
 * Terminates libraries used in digidoc implementation.
 */
void digidoc::terminate()
{
    X509CertStore::destroy();

    XmlConf::destroy();

    // Terminate Apache XML Security library.
    XSECPlatformUtils::Terminate();

    // Terminate Apache Xerces library.
    xercesc::XMLPlatformUtils::Terminate();

    // Try to delete temporary files created with the util::File::tempFileName, tempDirectory and createTempDirectory functions.
    util::File::deleteTempFiles();

    m_appInfo.clear();
}

/**
 * @return returns container type.
 */
ADoc::DocumentType ADoc::documentType() const
{
    return ADoc::UnknownType;
}

