#include "Conf.h"

#include "log.h"
#include "crypto/Digest.h"

using namespace digidoc;

Conf* Conf::INSTANCE = 0;
const Conf::OCSPConf Conf::ocsplist[] = {
    { "ESTEID-SK", "http://ocsp.sk.ee", "ESTEID-SK OCSP RESPONDER 2005" },
    { "ESTEID-SK 2007", "http://ocsp.sk.ee", "ESTEID-SK 2007 OCSP RESPONDER 2010" },
    { "ESTEID-SK 2011", "http://ocsp.sk.ee", "SK OCSP RESPONDER 2011" },
    { "EID-SK", "http://ocsp.sk.ee", "EID-SK OCSP RESPONDER" },
    { "EID-SK 2007", "http://ocsp.sk.ee", "EID-SK 2007 OCSP RESPONDER 2010" },
    { "EID-SK 2011", "http://ocsp.sk.ee", "SK OCSP RESPONDER 2011" },
    { "KLASS3-SK", "http://ocsp.sk.ee", "KLASS3-SK OCSP RESPONDER 2009" },
    { "KLASS3-SK 2010", "http://ocsp.sk.ee", "KLASS3-SK 2010 OCSP RESPONDER" },
    { "TEST-SK", "http://www.openxades.org/cgi-bin/ocsp.cgi", "TEST-SK OCSP RESPONDER 2005" },
    { "TEST of ESTEID-SK 2011", "http://www.openxades.org/cgi-bin/ocsp.cgi", "TEST of SK OCSP RESPONDER 2011" },
    { "TEST of EID-SK 2011", "http://www.openxades.org/cgi-bin/ocsp.cgi", "TEST of SK OCSP RESPONDER 2011" },
    { "TEST of KLASS3-SK 2010", "http://www.openxades.org/cgi-bin/ocsp.cgi", "TEST of SK OCSP RESPONDER 2011" } };

Conf* Conf::getInstance()
{
	return INSTANCE;
}

/**
 * Init global Conf with conf
 * @param conf implementation to use
 **/
void Conf::init(Conf *conf)
{
    delete INSTANCE;
    INSTANCE = conf;
}

bool Conf::isInitialized()
{
    return INSTANCE ? 1 : 0;
}

void Conf::destroy()
{
    delete INSTANCE;
    INSTANCE = 0;
}

int Conf::getLogLevel() const { return Log::InfoType; }
std::string Conf::getLogFile() const { return ""; }
std::string Conf::getDigestUri() const { return URI_SHA256; }
std::string Conf::getSignatureUri() const { return URI_RSA_SHA256; }
std::string Conf::getManifestXsdPath() const { return "schema/OpenDocument_manifest.xsd"; }
std::string Conf::getXadesXsdPath() const { return "schema/XAdES.xsd"; }
std::string Conf::getDsigXsdPath() const { return "schema/xmldsig-core-schema.xsd"; }
std::string Conf::getPKCS11DriverPath() const { return PKCS11_MODULE; }
Conf::OCSPConf Conf::getOCSP(const std::string &issuer) const
{
    for(size_t i = 0; i < sizeof(ocsplist); ++i)
        if(ocsplist[i].issuer == issuer)
            return ocsplist[i];
    return Conf::OCSPConf();
}
std::string Conf::getCertStorePath() const { return CERTS_PATH; }
std::string Conf::getProxyHost() const { return ""; }
std::string Conf::getProxyPort() const { return ""; }
std::string Conf::getProxyUser() const { return ""; }
std::string Conf::getProxyPass() const { return ""; }
std::string Conf::getPKCS12Cert() const { return ""; }
std::string Conf::getPKCS12Pass() const { return ""; }
bool Conf::getPKCS12Disable() const { return true; }
