#if !defined(__LOG_H_INCLUDED__)
#define __LOG_H_INCLUDED__

#include "Exports.h"

#include <stdarg.h>
#include <stdio.h>
#include <iostream>

namespace digidoc
{
    class EXP_DIGIDOC Log
    {
    public:
        enum LogType
        {
            ErrorType = 0,
            WarnType,
            InfoType,
            DebugType
        };

        static std::string format(const char *fmt, ...);
        static void out(LogType type, const char *file, unsigned int line, const char *format, ...);
        static void dbgPrintfMemImpl(const char *msg, const void *ptr, size_t size, const char *file, int line);

    private:
        static std::string formatArgList(const char *fmt, va_list args);
    };
}

#define ERR(...) digidoc::Log::out(digidoc::Log::ErrorType, __FILE__, __LINE__, __VA_ARGS__)
#define WARN(...) digidoc::Log::out(digidoc::Log::WarnType, __FILE__, __LINE__, __VA_ARGS__)
#define INFO(...) digidoc::Log::out(digidoc::Log::InfoType, __FILE__, __LINE__, __VA_ARGS__)
#define DEBUG(...) digidoc::Log::out(digidoc::Log::DebugType, __FILE__, __LINE__, __VA_ARGS__)
#define DEBUG2(FILE,LINE,...) digidoc::Log::out(digidoc::Log::DebugType, FILE, LINE, __VA_ARGS__)
#define DEBUGMEM(msg, ptr, size) digidoc::Log::dbgPrintfMemImpl(msg, ptr, size, __FILE__, __LINE__)

#define THROW_BDOCEXCEPTION(...) throw BDocException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__))
#define THROW_BDOCEXCEPTION_CAUSE(_cause, ...) throw BDocException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__), _cause)
#define THROW_IOEXCEPTION(...) throw IOException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__))
#define THROW_OCSPEXCEPTION(rsc, ...) throw OCSPException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__), rsc)
#define THROW_SIGNEXCEPTION(...) throw SignException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__))
#define THROW_SIGNEXCEPTION_CAUSE(_cause, ...) throw SignException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__), _cause)
#define THROW_SIGNATUREEXCEPTION(...) throw SignatureException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__))
#define THROW_SIGNATUREEXCEPTION_CAUSE(_cause, ...) throw SignatureException(__FILE__, __LINE__, digidoc::Log::format(__VA_ARGS__), _cause)

#endif // !defined(__LOG_H_INCLUDED__)
